@@ -1,25 +1,25 @@
 """Defines any IO utilities used by isort"""
+import dataclasses
 import re
 import tokenize
 from contextlib import contextmanager
 from io import BytesIO, StringIO, TextIOWrapper
 from pathlib import Path
-from typing import Callable, Iterator, TextIO, Union
+from typing import Any, Callable, Iterator, TextIO, Union
 
-from isort._future import dataclass
 from isort.exceptions import UnsupportedEncoding
 
-_ENCODING_PATTERN = re.compile(br"^[ \t\f]*#.*?coding[:=][ \t]*([-_.a-zA-Z0-9]+)")
+_ENCODING_PATTERN = re.compile(rb"^[ \t\f]*#.*?coding[:=][ \t]*([-_.a-zA-Z0-9]+)")
 
 
-@dataclass(frozen=True)
+@dataclasses.dataclass(frozen=True)
 class File:
     stream: TextIO
     path: Path
     encoding: str
 
     @staticmethod
-    def detect_encoding(filename: str, readline: Callable[[], bytes]):
+    def detect_encoding(filename: Union[str, Path], readline: Callable[[], bytes]) -> str:
         try:
             return tokenize.detect_encoding(readline)[0]
         except Exception:
@@ -28,16 +28,14 @@ class File:
     @staticmethod
     def from_contents(contents: str, filename: str) -> "File":
         encoding = File.detect_encoding(filename, BytesIO(contents.encode("utf-8")).readline)
-        return File(  # type: ignore
-            stream=StringIO(contents), path=Path(filename).resolve(), encoding=encoding
-        )
+        return File(stream=StringIO(contents), path=Path(filename).resolve(), encoding=encoding)
 
     @property
-    def extension(self):
+    def extension(self) -> str:
         return self.path.suffix.lstrip(".")
 
     @staticmethod
-    def _open(filename):
+    def _open(filename: Union[str, Path]) -> TextIOWrapper:
         """Open a file in read only mode using the encoding detected by
         detect_encoding().
         """
@@ -59,14 +57,14 @@ class File:
         stream = None
         try:
             stream = File._open(file_path)
-            yield File(stream=stream, path=file_path, encoding=stream.encoding)  # type: ignore
+            yield File(stream=stream, path=file_path, encoding=stream.encoding)
         finally:
             if stream is not None:
                 stream.close()
 
 
 class _EmptyIO(StringIO):
-    def write(self, *args, **kwargs):
+    def write(self, *args: Any, **kwargs: Any) -> None:  # type: ignore # skipcq: PTC-W0049
         pass
 
 
