@@ -10,6 +10,7 @@ import re
 import stat
 import subprocess  # nosec: Needed for gitignore support.
 import sys
+from dataclasses import dataclass, field
 from functools import lru_cache
 from pathlib import Path
 from typing import (
@@ -30,7 +31,6 @@ from typing import (
 from warnings import warn
 
 from . import sorting, stdlibs
-from ._future import dataclass, field
 from .exceptions import (
     FormattingPluginDoesNotExist,
     InvalidSettingsPath,
@@ -38,7 +38,7 @@ from .exceptions import (
     SortingFunctionDoesNotExist,
     UnsupportedSettings,
 )
-from .profiles import profiles
+from .profiles import profiles as profiles
 from .sections import DEFAULT as SECTION_DEFAULTS
 from .sections import FIRSTPARTY, FUTURE, LOCALFOLDER, STDLIB, THIRDPARTY
 from .utils import Trie
@@ -318,7 +318,7 @@ class Config(_Config):
             config_vars.pop("_skips")
             config_vars.pop("_skip_globs")
             config_vars.pop("_sorting_function")
-            super().__init__(**config_vars)  # type: ignore
+            super().__init__(**config_vars)
             return
 
         # We can't use self.quiet to conditionally show warnings before super.__init__() is called
@@ -525,7 +525,7 @@ class Config(_Config):
         if unsupported_config_errors:
             raise UnsupportedSettings(unsupported_config_errors)
 
-        super().__init__(sources=tuple(sources), **combined_config)  # type: ignore
+        super().__init__(sources=tuple(sources), **combined_config)
 
     def is_supported_filetype(self, file_name: str) -> bool:
         _root, ext = os.path.splitext(file_name)
